@@ -24,4 +24,35 @@ extern GtkWidget *edit_item (struct todo_item *item,
 extern void categories_menu (void);
 extern void refresh_items (void);
 
+/* screen geometry information */
+extern gboolean mode_landscape;
+extern gboolean large_screen;
+
+/* list store column definitions */
+enum
+{
+    COL_ICON,
+    COL_SUMMARY,
+    COL_STRIKETHROUGH,
+    COL_DATA,
+    COL_STATUS,
+    COL_DUE,
+    COL_CATEGORY,
+    COL_PRIORITY,
+    COL_PRIORITY_TEXT,
+    NUM_COLUMNS
+};
+
+struct menu_map
+{
+  gchar *string;
+  gint value;
+};
+
+extern struct menu_map state_map[];
+
+#ifdef IS_HILDON
+GtkWidget *main_appview;  
+#endif
+
 #endif
